@@ -45,8 +45,9 @@ class IInnerTable(IContentProvider):
     table_label = TextLine(title="Inner table label")
 
 
-class ITableElementName(Interface):
-    """Table element name interface"""
+@template_config(template='templates/table-multiple.pt')
+class IMultipleTableView(IInnerAdminView):
+    """Multiple table view"""
 
 
 class ITableWithActions(Interface):
